Documentation
¶
Overview ¶
Package filter provides an interface for matching strings against a set of string filters.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Strict string `mapstructure:"strict"`
Regex string `mapstructure:"regexp"`
// contains filtered or unexported fields
}
Config configures the matching behavior of a Filter.
type Filter ¶
type Filter interface {
// Matches returns true if the given value matches at least one
// of the filters encapsulated by the Filter.
Matches(any) bool
}
Filter is an interface for matching values against a set of filters.
func CreateFilter ¶
CreateFilter creates a Filter out of a set of Config configuration objects.
Click to show internal directories.
Click to hide internal directories.